@@ -4,7 +4,7 @@ test_that("table_initialize() has proper columns", {
   skip_on_cran()
   skip_on_travis()
   
-  mazama_initialize()
+  initializeMazamaSpatialUtils()
   locationTbl <- table_initialize()
   expect_equal(names(locationTbl), MazamaLocationUtils::coreMetadataNames)
 })
